@@ -275,28 +275,19 @@ struct car {
 };
 
 _Bool is_viable(double time_remaining, double boost_accel, Vector gravity, struct car me, Vector target) {
-    // printf("C:\n");
     Vector T = double_to_vector(time_remaining);
     Vector xf = add(add(me.location, multiply(me.velocity, T)), multiply(multiply(multiply(double_to_vector(0.5), gravity), T), T));
-    // printf("Before xf: (%f, %f, %f)\n", xf.x, xf.y, xf.z);
     Vector vf = add(me.velocity, multiply(gravity, T));
-    // printf("Before vf: (%f, %f, %f)\n", vf.x, vf.y, vf.z);
 
     if (me.airborne == -1) {
         xf = add(xf, multiply(me.up, double_to_vector(jump_speed * (2 * time_remaining - jump_max_duration) + jump_acc * (time_remaining * jump_max_duration - 0.5 * jump_max_duration * jump_max_duration))));
-        // printf("After xf: (%f, %f, %f)\n", xf.x, xf.y, xf.z);
         vf = add(vf, multiply(me.up, double_to_vector(2 * jump_speed + jump_acc * jump_max_duration)));
-        // printf("After vf: (%f, %f, %f)\n", vf.x, vf.y, vf.z);
     }
 
     Vector delta_x = sub(target, xf);
-    // printf("Delta x: (%f, %f, %f)\n", delta_x.x, delta_x.y, delta_x.z);
     Vector f = normalize(delta_x).vector;
-    // printf("f: (%f, %f, %f)\n", f.x, f.y, f.z);
 
     double phi = angle(delta_x, me.forward);
-    // printf("Car forward: (%f, %f, %f)\n", me.forward.x, me.forward.y, me.forward.z);
-    // printf("Phi: %f\n", phi);
     double turn_time = 0.7 * (2 * sqrt(phi / 9));
     double tau1 = turn_time * cap(1 - 0.3 / phi, 0, 1);
     double required_acc = (2 * magnitude(delta_x) / ((time_remaining - tau1) * (time_remaining - tau1)));
@@ -307,11 +298,8 @@ _Bool is_viable(double time_remaining, double boost_accel, Vector gravity, struc
     Vector velocity_estimate = add(vf, multiply(f, double_to_vector(boost_accel * (tau2 - tau1))));
 
     _Bool enough_boost = boost_estimate < 0.95 * me.boost;
-    // printf("Enought boost: %s\n", enough_boost ? "True" : "False");
     _Bool enough_time = fabs(ratio) < 0.9;
-    // printf("Enought time: %s\n", enough_time ? "True" : "False");
     _Bool enough_speed = magnitude(velocity_estimate) < 0.9 * max_speed;
-    // printf("Enought speed: %s\n", enough_speed ? "True" : "False");
 
     return enough_speed && enough_boost && enough_time;
 };
@@ -327,13 +315,12 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     if (!pst_crrctn.swapped) {
         Vector left_vector = normalize(sub(pst_crrctn.left, ball_location)).vector;
         Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
-        Vector best_shot_vector = clamp(direction, left_vector, right_vector);
+        r.ball_intercept = sub(ball_location, multiply(clamp(direction, left_vector, right_vector), double_to_vector(175)));
 
-        if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(200))), 1) && fast_shot(me.location, ball_location, time_remaining, cap_, 250)) {
-            r.ball_intercept = sub(ball_location, multiply(best_shot_vector, double_to_vector(200)));
+        if (in_field(r.ball_intercept, 1) && fast_shot(me.location, ball_location, time_remaining, cap_, 250)) {
             double slope = find_slope(r.ball_intercept, car_to_ball);
 
-            if (slope > 1 && is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
+            if (slope > 0 && is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
                 r.found = 1;
         }
     }
@@ -346,12 +333,12 @@ struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double boo
     r.found = -1;
 
     Vector car_to_ball = sub(ball_location, me.location);
-    Vector best_shot_vector = normalize(car_to_ball).vector;
+    r.ball_intercept = sub(ball_location, multiply(normalize(car_to_ball).vector, double_to_vector(175)));
 
-    if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(200))), 1)) {
-        r.ball_intercept = sub(ball_location, multiply(best_shot_vector, double_to_vector(92)));
+    if (in_field(r.ball_intercept, 1)) {
+        double slope = find_slope(r.ball_intercept, car_to_ball);
 
-        if (is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
+        if (slope > 0 && is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
             r.found = 1;
     }
 
